<?php
namespace ONLINE_ADA;

use ONLINE_ADA\Helper;
use League\Csv\Writer;


add_action('rest_api_init', __NAMESPACE__ .'\\csv_page_download');
function csv_page_download()
{
    register_rest_route('ada-plugin/v1', '/pagecsv', array(
        'methods' => 'GET',
        'callback' => __NAMESPACE__ . '\\page_csv'
    ));
}

function page_csv($request)
{
    $scan_data = Helper::get_scan_data_automatic(sanitize_text_field($_GET["scan_id"]), Plugin::$instance->info["db_row_limit"]);
    
    if( !$scan_data ){ return; }
    $articles = Helper::getWcagArticlesModel(2);
    $guidelines = Helper::getWcagArticlesModel(1, true);

    $formatted = [];
    $issue_number = 1;
    foreach ($scan_data AS $cat_title => $cat_items) {
        if($cat_title == "issues"){ continue; }

        foreach($cat_items AS $item){
            $page = "Homepage";
            if(isset($item["page"])){
                $page = home_url()."/".$item["page"];
            }
            $articles = "best practice";
            
            if(!empty($item["articles"])){
                $articles = '"';
                foreach($item["articles"] AS $index => $art){
                    $articles .= $art;
                    $articles .= ', ';
                }
                $articles = rtrim($articles, ", ");
                $articles .= '"';
            }

            $types = "BP";
            
            if(!empty($item["types"])){
                $types = '"';
                $convert = [
                    "wcag level A" => "A",
                    "wcag level AA" => "AA",
                    "contrast"  => "AA"
                ];
                
                foreach($item["types"] AS $index => $type){
                    if(empty($convert[$type])){continue;}
                    $types .= $convert[$type];
                    $types .= ', ';
                    
                }
                $types = rtrim($types, ", ");
                $types .= '"';
            }

            $html = stripslashes($item["html"]);
            if(strlen(stripslashes($item["html"])) > 300){
                $html = substr(stripslashes($item["html"]), 0, 300) . " [... truncated]";
            }

            $message = $item["message"];
            if(empty($message)){
                $message = $item["issueData"]["any"][0]["message"];
            }
            
            $formatted[] = [ $issue_number, $page, $articles, $types, $message, $html ];
            $issue_number++;   
        }
    }

    $csv = Writer::createFromFileObject(new \SplTempFileObject(), 'w');
    $csv->setNewline("\n");

    //Header row
    $csv->insertOne(["Issue #", "Page", "Article #", "WCAG Level", "Description", "Source Code"]);
    foreach ($formatted as $array) {
        $csv->insertOne($array);
    }
    $csv->insertOne([""]);

    $csv->setOutputBOM(Writer::BOM_UTF8);
    $title = strtolower($_GET["scan_title"]);
    $title = explode(" ", $title);
    $title = implode("_", $title);
    $title = explode("-", $title);
    $title = implode("_", $title);
    $csv->output( $title . "-report.csv");
    die;
}