<?php
namespace ONLINE_ADA;
?>

<div class="ll-container-fluid">
	<div class="wrap getting-started">
		<h1><?php echo get_admin_page_title(); ?></h1>
		<div class="ll-row">
			<div class="ll-col-9">
				<h2>How to start a scan:</h2>
				<ul>
					<li>On activation, the plugin creates a sitemap for you by compiling a list of posts and pages, so all you have to do is find the "Accessibility" menu on the left side of the admin dashboard and choose "Start Scan"</li>
					<li>You can choose from several options on this page. Those options include choosing whether to use pages with query strings, include a color blind report, which shows you a representation of your homepage through the eyes of someone suffering from any of 8 different color blindnesses, or schedule a scan to run on a schedule, like once a month.</li>
				</ul>
				<br>
				<h2>How to change your sitemap:</h2>
				<div>The sitemap page is available to paid accounts and allows you to completely customize which pages your scan will include. An overview of your options include:</div>
				<ul>
					<li>
						<span><strong>Re-Create sitemap</strong></span>
						<div>This tab will allow you to let the plugin gather a list of all your posts and pages automatically and generate a sitemap for you.</div>
					</li>
					<li>
						<span><strong>Upload a sitemap</strong></span>
						<div>Here you can upload a sitemap file you're created yourself. There are numerous ways to do this and google even offers a free service. Accepted file types include .xml, .csv, .xls, and .xlsx.</div>
					</li>
					<li>
						<span><strong>Review Sitemap</strong></span>
						<div>Once a sitemap has been generated, either through uploading a file or letting the plugin create one for you, you can review the individual pages here. Pages are divided into 2 categories: Query Links and Non Query Links. Any page whose URL includes a question mark (?) in it will be considered a Query Link. Whether or not to include them in a scan is an option when starting a new scan. This tab gives you the ability to add any pages the sitemap generation missed, or remove any you don't wish to scan. When you are done adding and removing, click "Save sitemap" at the bottom, and you're all set.</div>
					</li>
				</ul>

				<br>
				<h2>Scan Results and Scheduled Scans:</h2>
				<div>Scans are grouped in 3 ways: Trash, Future, and Complete (Published). The "Scan Results" page is your primary location for viewing completed scans and getting access to your scan reports. The Scheduled scans is strictly for viewing scans that have been set to run in the future.</div>
				<br>
				<h2>Guidelines:</h2>
				<div>This page houses the technical details of the WCAG 2.1 Web Accessibility Guidelines. Throughout the scan report you will find links to "learn more" about a particular issue. This is where those links will take you. Here you can see in-depth explanations of what each WCAG rule means, along with helpful tips for intepreting them. If you would like to see the actual WCAG reference page, you can get to it by either clicking on the links at the top of this page or by clicking on the Principles, which will take you right to that category on the reference page.</div>
				<br>
				<h2>License Page:</h2>
				<div>This is where you can enter a license if you've purchased one from <a href="https://adaplugin.com/purchase">adaplugin.com</a>. This license is backwards compatible with the previous version of our plugin, the Section 508 plugin. There are 3 license states to be aware of: The license field is empty, The license field has a value but has not been activated, and a license has been activated. In the first 2 circumstances, the plugin will be considered to be in "Free" mode, but the scenario where a license is entered but not active is treated as though a license has expired. This will throw a message when running a scan about the license not being validated. Only when a license is entered and "active" will the plugin switch to paid version and unlock all features.</div>
				<br>
				<h2>Free versus Paid versions:</h2>
				<div>A free version of the plugin is available to use for as long as you like, but has a few limitations. Firstly, you will not be able to customize your sitemap. Secondly, any scans run will only return results for your homepage.</div>
				<br>
				<h2>Scan Report:</h2>
				<div>The scan report is the comprehensive list of issues returned by the scan.</div>
				<ul>
					<li>
						<span><strong>The star rating:</strong><span>
						<div>The star rating is a score out of 5 given to your site for the various types of issues we scan for: Section 508 errors, WCAG Level A, WCAG Level AA, and Contrast. These scores are based off of the number of errors found under each category, and your global score is the average of these individual scores.</div>
					</li>
					<li>
						<span><strong>Color Blindness PDF Viewer:</strong><span>
						<div>If you opted to have the scan include the color blind report, you will see this feature under the star scores. Clicking on the PDF VIEWER will show you a downloadable representation of your site's homepage filtered through 8 different color blind lenses. Once this report has been included once on your site, a local copy is stored on your website and therefor is not required to be run again unless you change your homepage.</div>
					</li>
					<li>
						<span><strong>Detailed Reports - Tabs:</strong><span>
						<div>There is a lot of information to view in the scan report, so we've provided a couple of different ways to see these results depending on your preference. The first view is by Page. This groups all errors by the page they were found on and can be viewed by expanding one of the headers with the name of the page on it below. The second view is by Object, which groups the errors by HTML element so that specific types of errors can be easier to locate, like all forms, or tables, etc.</div>
					</li>
					<li>
						<span><strong>Detailed Reports - Filters:</strong><span>
						<div>To the left of each error in the report are icons representing what type of error this was. The row of checkboxes directly below the View By Page and View By Object tabs is the filters row, and unselecting any of these checkboxes will hide errors of that type.</div>
					</li>
					<li>
						<span><strong>Site Updates:</strong><span>
						<div>This tab provides you with an overview of all of the images on your site, broken up in groups of 10. Here you can easily see which images are not considered compliant and which ones are (by toggling "show valid images" at the top). On any image in either of the lists you may enter an alt text into the description field OR mark it as decorative and click save. Marking an image as decorative will remove it's alt text and store it as compliant.</div>
					</li>
					<li>
						<span><strong>Download Your Report:</strong><span>
						<div>This feature provides you with a CSV representation of the report</div>
					</li>
				</ul>
			</div>
			<div class="ll-col-3">
				<div class="wcag-sidebar">
					<div class="wcag-widget">
						<p><strong><abbr title="Americans with Disabilities Act">Online ADA</abbr> Accessibility Tool</strong></p>
						<p>
							<a href="<?php echo esc_attr(admin_url('post-new.php?post_type=wcag_scan')); ?>" class="button button-primary">New Scan</a>
							<a href="<?php echo esc_attr(admin_url('edit.php?post_type=wcag_scan')); ?>" class="button button-secondary">Scan Results</a>
						</p>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>